lagrange: Langrangian Functions for Bregman Distances with Linear...

Description Usage Arguments Details

Description

Use lagrange_ent for the unnormalized relative entropy.

Usage

1
2
3
4
5
lagrange_ent(coefs, cmat, target, base_weights)

lagrange_bent(coefs, cmat, target, base_weights)

lagrange_sent(coefs, cmat, target, base_weights)

Arguments

coefs

vector of Lagrangian multipliers.

cmat

a matrix that determines the basis of a linear subspace which define the equality constraints of the optimization problem.

target

the target margins of the linear equality constraints. This vector should have a length equal to the number of columns in cmat.

base_weights

a vector of sampling weights with length equal to the number of rows in cmat.

Details

Use lagrange_bent for the binary relative entropy.

Use lagrange_sent for the shifted unnormalized relative entropy.


dewittpe/cbal-v1 documentation built on July 2, 2020, 6:24 p.m.