Description Usage Arguments Details
Use lagrange_ent for the unnormalized relative entropy.
1 2 3 4 5 | lagrange_ent(coefs, cmat, target, base_weights)
lagrange_bent(coefs, cmat, target, base_weights)
lagrange_sent(coefs, cmat, target, base_weights)
|
coefs |
vector of Lagrangian multipliers. |
cmat |
a matrix that determines the basis of a linear subspace which define the equality constraints of the optimization problem. |
target |
the target margins of the linear equality constraints. This vector
should have a length equal to the number of columns in |
base_weights |
a vector of sampling weights with length equal to the
number of rows in |
Use lagrange_bent for the binary relative entropy.
Use lagrange_sent for the shifted unnormalized relative entropy.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.